@@ -323,13 +323,15 @@ def get_pfx(bucket, key, profile=None):
 
 def renew_cert(
         ns, hostname, alt_domains=None,
-        email=None, bucket=None, tmp_dir=None, profile=None, **kwargs):
+        email=None, bucket=None, tmp_dir=None, profile=None,
+        bucket_profile=None, **kwargs):
     if alt_domains:
         if isinstance(alt_domains, str):
             alt_domains = alt_domains.split(',')
     else:
         alt_domains = []
-    _, account_key, key = get_certificate_from_s3(bucket, ns, hostname, profile)
+    _, account_key, key = get_certificate_from_s3(
+        bucket, ns, hostname, bucket_profile)
     client = Client(
         hostname, domain_alt_names=alt_domains, contact_email=email,
         provider=Route53Dns(profile), account_key=account_key,
@@ -338,11 +340,11 @@ def renew_cert(
     if not account_key:
         client.acme_register()
         content = client.account_key
-        save_account_key(bucket, ns, content, tmp_dir, profile)
+        save_account_key(bucket, ns, content, tmp_dir, bucket_profile)
     if not key:
         client.create_certificate_key()
         content = client.certificate_key
-        save_key(bucket, ns, hostname, content, tmp_dir, profile)
+        save_key(bucket, ns, hostname, content, tmp_dir, bucket_profile)
     certificate = client.renew()
     account_key = client.account_key
     key = client.certificate_key
@@ -444,11 +446,16 @@ def request_cert(ctx, filename, profile, defaults):
     pfx_password = values.pop('pfx_password', None)
     profile = profile or config_profile
     ns = namespaces[0]
+    bucket = values.pop('bucket', None)
+    buckets = values.get('buckets') or []
+    bucket_profile = profile
+    if buckets:
+        bucket = buckets[0]['name']
+        bucket_profile = buckets[0].get('profile') or profile
     certificate, account_key, key = renew_cert(
-        **values, ns=ns, profile=profile)
+        **values, ns=ns, profile=profile,
+        bucket=bucket, bucket_profle=bucket_profile)
     tmp_dir = values.pop('tmp_dir', '/tmp')
-    bucket = values.pop('bucket')
-    buckets = values.pop('buckets') or []
     save_to_file(
         ctx, tmp_dir, values['hostname'],
         certificate, account_key, key)
@@ -715,40 +722,72 @@ def install_cert_on_windows(
     """
     pull a file from s3 and install in the localmachine/my cert store
     """
-    import clr
+    import platform
+    from cryptography.hazmat.primitives.serialization import pkcs12
+    from cryptography.hazmat.primitives import hashes
     print('getting cert')
     pfx_data = get_pfx(bucket, key, profile)
-    password = None
+    print('getting thumbprint')
+    _, cert, _ = pkcs12.load_key_and_certificates(pfx_data, pfx_password)
+    thumbprint = cert.fingerprint(hashes.SHA1()).hex().upper()
+    f = NamedTemporaryFile(mode='w', delete=False)  # pylint: disable=consider-using-with
+    filename = f.name
+    print(f'importing pfx to cert store from {filename}')
+    with open(filename, 'wb') as f:
+        f.write(pfx_data)
+    cmdlet = ''
+    e = {}
     if pfx_password:
-        from System.Net import NetworkCredential
-        password = NetworkCredential('', pfx_password)
-        password = password.Password
-    from System.Security.Cryptography.X509Certificates import X509KeyStorageFlags
-    from System.Security.Cryptography.X509Certificates import X509Certificate2
-    from System.Security.Cryptography.X509Certificates import X509Store
-    from System.Security.Cryptography.X509Certificates import StoreName
-    from System.Security.Cryptography.X509Certificates import StoreLocation
-    from System.Security.Cryptography.X509Certificates import OpenFlags
-    store = store or StoreName.My
-    root_store = StoreLocation.LocalMachine
-    pfx = X509Certificate2()
-    flags = X509KeyStorageFlags.Exportable
-    flags |= X509KeyStorageFlags.MachineKeySet
-    flags |= X509KeyStorageFlags.PersistKeySet
-    pfx.Import(pfx_data, password, flags)
-    p = X509Store(store, root_store)
-    p.Open(OpenFlags.ReadWrite | OpenFlags.OpenExistingOnly)
-    exists = False
-    t = pfx.Thumbprint
-    for x in p.Certificates:
-        if x.Thumbprint == t:
-            print('cert already exists in cert store')
-            exists = True
-            break
-    if not exists:
-        p.Add(pfx)
-    p.Close()
-    return t
+        password = '-password (ConvertTo-SecureString -f -a $env:SEDGE_PASSWORD)'
+        e['SEDGE_PASSWORD'] = pfx_password
+    else:
+        password = "-password $null"
+    if store:
+        store_arg = rf"-certstorelocation 'cert:\localmachine\{store}'"
+    else:
+        store_arg = r'-certstorelocation cert:\localmachine\my'
+    if platform.release().startswith('2008'):
+        cmdlet = """
+        using namespace System.Security.Cryptography.X509Certificates
+        function Import-PfxCertificate {
+            param([string]$filepath
+              , [string]$root_store = 'localmachine'
+              , [string]$store = 'My'
+              , [security.securestring]$password = $null)
+            Write-Host "importing $filepath"
+            $pfx = new-object X509Certificate2
+            $flags = [X509KeyStorageFlags]::Exportable
+            $flags = $flags -bor [X509KeyStorageFlags]::MachineKeySet
+            $flags = $flags -bor [X509KeyStorageFlags]::PersistKeySet
+            $pfx.import($filepath, $password, $flags)
+            $p = new-object X509Store($store, $root_store)
+            $p.open('MaxAllowed')
+            $exists = $false
+            foreach ($x in $p.certificates) {
+                if ($x.thumbprint -eq $pfx.thumbprint) {
+                    Write-Host 'cert already exists in cert store'
+                    $exists = $true
+                }
+            }
+            if (!($exists)) {
+                $p.add($pfx)
+            }
+            $p.close()
+            return $pfx.thumbprint
+        }
+        """
+        store_arg = ''
+    lines = [
+        cmdlet,
+        f"$t = Import-PfxCertificate -filepath '{filename}' {password} "
+        f"{store_arg}",
+        'Write-Host $t',
+    ]
+    c = '\n'.join(lines)
+    ctx.run(c, env=e)
+    print(f'removing {filename}')
+    os.remove(filename)
+    return thumbprint
 
 
 def is_linux():
